@@ -50,7 +50,6 @@
 package com.openexchange.messaging.sms.osgi;
 
 import static com.openexchange.messaging.sms.osgi.MessagingSMSServiceRegistry.getServiceRegistry;
-import org.apache.commons.logging.Log;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.http.HttpService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
@@ -66,7 +65,7 @@ import com.openexchange.osgi.ServiceRegistry;
  */
 public class Activator extends DeferredActivator {
 
-    private static transient final Log LOG = com.openexchange.log.Log.loggerFor(Activator.class);
+    private static transient final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Activator.class);
 
     private volatile ServletRegisterer servletRegisterer;
 
@@ -83,9 +82,7 @@ public class Activator extends DeferredActivator {
 
     @Override
     protected void handleAvailability(final Class<?> clazz) {
-        if (LOG.isWarnEnabled()) {
-            LOG.warn("Absent service: " + clazz.getName());
-        }
+        LOG.warn("Absent service: {}", clazz.getName());
         getServiceRegistry().addService(clazz, getService(clazz));
         if (HttpService.class.equals(clazz)) {
             servletRegisterer.registerServlet();
@@ -94,9 +91,7 @@ public class Activator extends DeferredActivator {
 
     @Override
     protected void handleUnavailability(final Class<?> clazz) {
-        if (LOG.isInfoEnabled()) {
-            LOG.info("Re-available service: " + clazz.getName());
-        }
+        LOG.info("Re-available service: {}", clazz.getName());
         if (HttpService.class.equals(clazz)) {
             servletRegisterer.unregisterServlet();
         }
@@ -124,7 +119,7 @@ public class Activator extends DeferredActivator {
 
             serviceRegistration = context.registerService(PreferencesItemService.class, new SMSPreferencesItem(), null);
         } catch (final Throwable t) {
-            LOG.error(t.getMessage(), t);
+            LOG.error("", t);
             throw t instanceof Exception ? (Exception) t : new Exception(t);
         }
     }
@@ -146,7 +141,7 @@ public class Activator extends DeferredActivator {
             getServiceRegistry().clearRegistry();
             ServletRegisterer.PREFIX.set(null);
         } catch (final Throwable t) {
-            LOG.error(t.getMessage(), t);
+            LOG.error("", t);
             throw t instanceof Exception ? (Exception) t : new Exception(t);
         }
     }
